@@ -1,8 +1,6 @@
 import requests
 import json
 
-from requests.models import Response
-
 from .helper import Helper
 
 """
@@ -19,20 +17,15 @@ from .helper import Helper
 
 
 class Others(Helper):
-    def __init__(self, base_url, org_pk, teams_pk, access_token, _csrf_token, headers):
-        self.base_url = base_url
-        self.org_pk = org_pk
-        self.teams_pk = teams_pk
-        self.access_token = access_token
-        self._csrf_token = _csrf_token
-        self.headers = headers
+    def __init__(self, base_url, org_pk, teams_pk, access_token, _csrf_token, headers, pagination):
+        super().__init__(base_url, org_pk, teams_pk, access_token, _csrf_token, headers, pagination)
 
     #### Goals ####
 
-    def get_goals_list(self):
+    def get_goals_list(self, page=1):
         """ Get the list of goals """
 
-        route = 'v1/goals/list/{0}/'.format(self.org_pk)
+        route = 'v1/goals/list/{0}/?page_size={1}&page={2}'.format(self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -184,10 +177,11 @@ class Others(Helper):
         xls_file.close()
         return self.process_response(response)
 
-    def get_projections_forecast_month_rule_list(self):
+    def get_projections_forecast_month_rule_list(self, page=1):
         """ Get the list of month rules """
 
-        route = 'v1/projections/forecast-month-rule/list/{0}/'.format(self.org_pk)
+        route = 'v1/projections/forecast-month-rule/list/{0}/?page_size={1}&page={2}'.format(
+            self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -246,10 +240,11 @@ class Others(Helper):
         response = requests.delete('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_projections_forecast_month_ruleset_list(self):
+    def get_projections_forecast_month_ruleset_list(self, page=1):
         """ Get the list of month rulesets """
 
-        route = 'v1/projections/forecast-month-ruleset/list/{0}/'.format(self.org_pk)
+        route = 'v1/projections/forecast-month-ruleset/list/{0}/?page_size={1}&page={2}'.format(
+            self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -309,14 +304,14 @@ class Others(Helper):
         response = requests.delete('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_projections_month_annexes_list(self, project_id):
+    def get_projections_month_annexes_list(self, project_id, page=1):
         """ Get the project month annexes list
 
         Keywords arguments:
         project_id -- id of the project
         """
 
-        route = 'v1/projections/months/annex/list/{0}/'.format(project_id)
+        route = 'v1/projections/months/annex/list/{0}/?page_size={1}&page={2}'.format(project_id, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -388,14 +383,14 @@ class Others(Helper):
         response = requests.delete('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_projections_month_fees_list(self, project_id):
+    def get_projections_month_fees_list(self, project_id, page=1):
         """ Get the month fees
 
         Keywords arguments:
         project_id -- id of the project
         """
 
-        route = 'v1/projections/months/fee/list/{0}/'.format(project_id)
+        route = 'v1/projections/months/fee/list/{0}/?page_size={1}&page={2}'.format(project_id, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -464,14 +459,14 @@ class Others(Helper):
         response = requests.delete('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_projections_month_phases_list(self, project_id):
+    def get_projections_month_phases_list(self, project_id, page=1):
         """ Get the month phases list
 
         Keywords arguments:
         project_id -- id of the project
         """
 
-        route = 'v1/projections/months/phase/list/{0}/'.format(project_id)
+        route = 'v1/projections/months/phase/list/{0}/?page_size={1}&page={2}'.format(project_id, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -555,12 +550,12 @@ class Others(Helper):
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_projections_roles_annex_list(self, project_pk):
+    def get_projections_roles_annex_list(self, project_pk, page=1):
         """ Get projections roles annex list
         Keyword argument:
         project_pk -- pk of the project
         """
-        route = 'v1/projections/roles/annex/list/{0}/'.format(project_pk)
+        route = 'v1/projections/roles/annex/list/{0}/?page_size={1}&page={2}'.format(project_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -602,12 +597,12 @@ class Others(Helper):
         response = requests.delete('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_projections_roles_phase_list(self, project_pk):
+    def get_projections_roles_phase_list(self, project_pk, page=1):
         """ Get projections roles phase list
         Keyword argument:
         project_pk -- pk of the project
         """
-        route = 'v1/projections/roles/phase/list/{0}/'.format(project_pk)
+        route = 'v1/projections/roles/phase/list/{0}/?page_size={1}&page={2}'.format(project_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -681,12 +676,12 @@ class Others(Helper):
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_projections_users_annex_list(self, project_pk):
+    def get_projections_users_annex_list(self, project_pk, page=1):
         """ Get projections users annex list  
         Keyword argument:
         project_pk -- pk of the project
         """
-        route = 'v1/projections/users/annex/list/{0}/'.format(project_pk)
+        route = 'v1/projections/users/annex/list/{0}/?page_size={1}&page={2}'.format(project_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
@@ -718,12 +713,12 @@ class Others(Helper):
         response = requests.patch('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response)
 
-    def get_projections_users_phase_list(self, project_pk):
+    def get_projections_users_phase_list(self, project_pk, page=1):
         """ Get projections users phase list 
         Keyword argument:
         project_pk -- pk of the project
         """
-        route = 'v1/projections/users/phase/list/{0}/'.format(project_pk)
+        route = 'v1/projections/users/phase/list/{0}/?page_size={1}&page={2}'.format(project_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
