@@ -5,13 +5,8 @@ from .helper import Helper
 
 
 class Time(Helper):
-    def __init__(self, base_url, org_pk, teams_pk, access_token, _csrf_token, headers):
-        self.base_url = base_url
-        self.org_pk = org_pk
-        self.teams_pk = teams_pk
-        self.access_token = access_token
-        self._csrf_token = _csrf_token
-        self.headers = headers
+    def __init__(self, base_url, org_pk, teams_pk, access_token, _csrf_token, headers, pagination):
+        super().__init__(base_url, org_pk, teams_pk, access_token, _csrf_token, headers, pagination)
 
     #### Timelogs ####
 
@@ -107,10 +102,10 @@ class Time(Helper):
         return self.process_response(response)
 
     ### Holidays ###
-    def get_timelogs_holidays_org(self):
+    def get_timelogs_holidays_org(self, page=1):
         """ Get the holidays list """
 
-        route = 'v1/timelogs/holidays/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/timelogs/holidays/list/{0}/?page_size={1}&page={2}'.format(self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -137,13 +132,14 @@ class Time(Helper):
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response)
 
-    def get_timelogs_holidays_team(self, team_pk):
+    def get_timelogs_holidays_team(self, team_pk, page=1):
         """ Get the holidays list for a team 
 
         team_pk -- pk of the team
         """
 
-        route = 'v1/timelogs/holidays/list/{0}/{1}/?page_size=999999'.format(self.org_pk, team_pk)
+        route = 'v1/timelogs/holidays/list/{0}/{1}/?page_size={2}&page={3}'.format(
+            self.org_pk, team_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -217,7 +213,7 @@ class Time(Helper):
         return self.process_response(response)
 
     ### Hourslogs ###
-    def get_timelogs_hourslogs_list(self, team_pk):
+    def get_timelogs_hourslogs_list(self, team_pk, page=1):
         """ Get the hourslogs list 
 
         Keyword argument : 
@@ -225,7 +221,7 @@ class Time(Helper):
         team_pk -- pk of the team
         """
 
-        route = 'v1/timelogs/hourslogs/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/hourslogs/list/{0}/?page_size={1}&page={2}'.format(team_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -262,7 +258,7 @@ class Time(Helper):
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response)
 
-    def get_timelogs_hourslogs_my_list(self, team_pk):
+    def get_timelogs_hourslogs_my_list(self, team_pk, page=1):
         """ Get the hourslogs list 
 
         Keyword argument : 
@@ -270,7 +266,7 @@ class Time(Helper):
         team_pk -- pk of the team
         """
 
-        route = 'v1/timelogs/hourslogs/my-list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/hourslogs/my-list/{0}/?page_size={1}&page={2}'.format(team_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -362,7 +358,7 @@ class Time(Helper):
         return self.process_response(response, True)
 
     ### Timeoff ###
-    def get_timelogs_my_timeoff_requests_list(self, team_pk):
+    def get_timelogs_my_timeoff_requests_list(self, team_pk, page=1):
         """ Get my timeoff requests 
 
         Keyword arguments :
@@ -370,11 +366,12 @@ class Time(Helper):
         team_pk -- pk of the team
         """
 
-        route = 'v1/timelogs/my-timeoff-requests/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/my-timeoff-requests/list/{0}/?page_size={1}&page={2}'.format(
+            team_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
-    def create_timelogs_my_timeoff_requests(self, team_pk, data):
+    def create_timelogs_my_timeoff_requests(self, team_pk, data, page):
         """ Create my timeoff requests 
 
         Keyword arguments :
@@ -403,11 +400,11 @@ class Time(Helper):
         }
         """
 
-        route = 'v1/timelogs/my-timeoff-requests/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/my-timeoff-requests/list/{0}/'.format(team_pk)
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response, True)
 
-    def get_timelogs_timeoff_requests_list(self, team_pk):
+    def get_timelogs_timeoff_requests_list(self, team_pk, page=1):
         """ Get timeoff requests 
 
         Keyword arguments :
@@ -415,7 +412,7 @@ class Time(Helper):
         team_pk -- pk of the team
         """
 
-        route = 'v1/timelogs/timeoff-requests/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/timeoff-requests/list/{0}/?page_size={1}&page={2}'.format(team_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -447,7 +444,7 @@ class Time(Helper):
         }
         """
 
-        route = 'v1/timelogs/timeoff-requests/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/timeoff-requests/list/{0}/'.format(team_pk)
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response, True)
 
@@ -465,7 +462,7 @@ class Time(Helper):
         }
         """
 
-        route = 'v1/timelogs/timeoff-balance/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/timeoff-balance/list/{0}/'.format(team_pk)
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response)
 
@@ -483,7 +480,7 @@ class Time(Helper):
         }
         """
 
-        route = 'v1/timelogs/timeoff-balance/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/timeoff-balance/list/{0}/'.format(team_pk)
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response)
 
@@ -547,7 +544,7 @@ class Time(Helper):
     def get_timelogs_types_list(self):
         """ Get timelogs type list """
 
-        route = 'v1/timelogs/types/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/timelogs/types/list/{0}/'.format(self.org_pk)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -571,10 +568,10 @@ class Time(Helper):
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response, True)
 
-    def get_timelogs_types_timeoff_list(self):
+    def get_timelogs_types_timeoff_list(self, page=1):
         """ Get timelogs types timeoff list """
 
-        route = 'v1/timelogs/types/timeoff/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/timelogs/types/timeoff/list/{0}/?page_size={1}&page={2}'.format(self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -644,10 +641,10 @@ class Time(Helper):
         return self.process_response(response, True)
 
     ### Week-config ###
-    def get_timelogs_week_config_list(self):
+    def get_timelogs_week_config_list(self, page=1):
         """ Get week config list """
 
-        route = 'v1/timelogs/week-config/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/timelogs/week-config/list/{0}/?page_size={1}&page={2}'.format(self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -782,7 +779,7 @@ class Time(Helper):
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_timelogs_week_list(self, start_date=""):
+    def get_timelogs_week_list(self, page=1, start_date=None):
         """ Get weeks list 
 
         Keyword arguments:
@@ -791,7 +788,9 @@ class Time(Helper):
         """
 
         route = 'v1/timelogs/weeks/list/{0}/'.format(self.org_pk)
-        parameters = "?start_date={0}&page_size=999999=".format(start_date)
+        parameters = "?page={0}&page_size={1}".format(page, self.pagination)
+        if start_date:
+            parameters += '&start_date={0}'.format(start_date)
 
         response = requests.get('{0}{1}{2}'.format(self.base_url, route, parameters), headers=self.headers)
         return self.process_response(response, True)
@@ -830,7 +829,7 @@ class Time(Helper):
         return self.process_response(response)
 
     ### Worklogs ###
-    def get_timelogs_worklogs_list(self, team_pk):
+    def get_timelogs_worklogs_list(self, team_pk, page=1):
         """ Get worklogs list 
 
         Keyword arguments:
@@ -838,7 +837,7 @@ class Time(Helper):
         team_pk -- pk of the team
         """
 
-        route = 'v1/timelogs/worklogs/list/{0}/?page_size=999999'.format(team_pk)
+        route = 'v1/timelogs/worklogs/list/{0}/?page_size={1}&page={2}'.format(team_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -955,11 +954,11 @@ class Time(Helper):
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def create_timeperiods_resource_planning_timeline(self):
+    def create_timeperiods_resource_planning_timeline(self, data):
         """ Create planning timeline """
 
         route = 'v1/timeperiods/resource-planning-timeline/{0}/'.format(self.org_pk)
-        response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers)
+        response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response)
 
     def get_timeperiods_resources_timeline(self, project_pk):
@@ -974,10 +973,11 @@ class Time(Helper):
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_timeperiods_role_annex_periods(self):
+    def get_timeperiods_role_annex_periods(self, page=1):
         """ Get role annex periods list """
 
-        route = 'v1/timeperiods/role-annex-periods/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/timeperiods/role-annex-periods/list/{0}/?page_size={1}&page={2}'.format(
+            self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -1098,10 +1098,10 @@ class Time(Helper):
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def get_user_period_list(self):
+    def get_user_period_list(self, team_pk):
         """ Get user period list"""
 
-        route = 'v1/timeperiods/user-period/list/{0}/'.format(self.org_pk)
+        route = 'v1/timeperiods/user-period/list/{0}/?team={1}'.format(self.org_pk, team_pk)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
@@ -1196,10 +1196,10 @@ class Time(Helper):
         return self.process_response(response)
 
     #### Roles ####
-    def get_roles_list(self):
+    def get_roles_list(self, page=1):
         """ Get roles list """
 
-        route = 'v1/roles/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/roles/list/{0}/?page_size={1}&page={2}'.format(self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -1220,10 +1220,10 @@ class Time(Helper):
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers, data=json.dumps(data))
         return self.process_response(response)
 
-    def get_roles_project_list(self):
+    def get_roles_project_list(self, page=1):
         """ Get roles project list """
 
-        route = 'v1/roles/project/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/roles/project/list/{0}/?page_size={1}&page={2}'.format(self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
@@ -1292,17 +1292,17 @@ class Time(Helper):
         response = requests.delete('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def create_bulk_action_add_roles(self):
+    def create_bulk_action_add_roles(self, project_pk):
         """ Create bulk action to add role to project """
 
-        route = 'v1/roles/roles/bulk/add/{0}/'.format(self.org_pk)
+        route = 'v1/roles/roles/bulk/add/{0}/?project={1}'.format(self.org_pk, project_pk)
         response = requests.post('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
-    def delete_bulk_action_add_roles(self):
+    def delete_bulk_action_add_roles(self, project_pk):
         """ Delete bulk action to add role to project """
 
-        route = 'v1/roles/roles/bulk/delete/{0}/'.format(self.org_pk)
+        route = 'v1/roles/roles/bulk/delete/{0}/?project={1}'.format(self.org_pk, project_pk)
         response = requests.delete('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response)
 
@@ -1349,10 +1349,10 @@ class Time(Helper):
         return self.process_response(response)
 
     #### Trips ####
-    def get_trips_list(self):
+    def get_trips_list(self, page=1):
         """ Get trips list """
 
-        route = 'v1/trips/list/{0}/?page_size=999999'.format(self.org_pk)
+        route = 'v1/trips/list/{0}/?page_size={1}&page={2}'.format(self.org_pk, self.pagination, page)
         response = requests.get('{0}{1}'.format(self.base_url, route), headers=self.headers)
         return self.process_response(response, True)
 
